@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import React from 'react'
@@ -38,6 +39,11 @@ import { event as currentEvent } from 'd3-selection'
 class DiagramViewer extends React.Component {
   static propTypes = {
     activeFilters: PropTypes.object,
+    argoAppDetailsContainerControl: PropTypes.shape({
+      argoAppDetailsContainerData: PropTypes.object,
+      handleArgoAppDetailsContainerUpdate: PropTypes.func,
+      handleErrorMsg: PropTypes.func
+    }),
     availableFilters: PropTypes.object,
     channelControl: PropTypes.object,
     handleLegendClose: PropTypes.func,
@@ -108,8 +114,10 @@ class DiagramViewer extends React.Component {
   }
 
   componentDidUpdate() {
+    const { secondaryLoad } = this.props
+
     if (!this.detailsViewUpdate && !this.props.showLegendView) {
-      this.generateDiagram()
+      this.generateDiagram(secondaryLoad)
     }
     this.detailsViewUpdate = false
   }
@@ -259,7 +267,8 @@ class DiagramViewer extends React.Component {
       showLegendView,
       handleLegendClose,
       nodes,
-      activeFilters
+      activeFilters,
+      argoAppDetailsContainerControl
     } = this.props
 
     const {
@@ -276,6 +285,8 @@ class DiagramViewer extends React.Component {
       handleClusterDetailsContainerUpdate: this
         .handleClusterDetailsContainerUpdate
     }
+    const pointerEventStyle = secondaryLoad ? { pointerEvents: 'none' } : {}
+
     return (
       <div className="diagramViewerDiagram" ref={this.setContainerRef}>
         {title && <div className="diagramTitle">{title}</div>}
@@ -291,7 +302,11 @@ class DiagramViewer extends React.Component {
             role="region"
             aria-label="zoom"
           >
-            <svg id={c.DIAGRAM_SVG_ID} className="topologyDiagram" />
+            <svg
+              id={c.DIAGRAM_SVG_ID}
+              className="topologyDiagram"
+              style={pointerEventStyle}
+            />
           </div>
           {secondaryLoad && (
             <div className="secondaryLoad">
@@ -325,6 +340,7 @@ class DiagramViewer extends React.Component {
             processActionLink={processActionLink}
             nodes={nodes}
             clusterDetailsContainerControl={clusterDetailsContainerControl}
+            argoAppDetailsContainerControl={argoAppDetailsContainerControl}
             activeFilters={activeFilters}
           />
         )}
@@ -405,7 +421,7 @@ class DiagramViewer extends React.Component {
     return filteringOn
   };
 
-  generateDiagram() {
+  generateDiagram(secondaryLoad) {
     // if dragging or searching don't refresh diagram
     if (this.isDragging) {
       return
@@ -443,7 +459,8 @@ class DiagramViewer extends React.Component {
       availableFilters,
       staticResourceData,
       showLayoutLoading: () => {
-        this.layoutLoadingRef.style.visibility = 'visible'
+        //this.layoutLoadingRef.style.visibility = 'visible'
+        this.layoutLoadingRef.style.display = 'block'
       }
     }
 
@@ -474,6 +491,10 @@ class DiagramViewer extends React.Component {
         // stop any current transitions
         this.zoomHelper.interruptElements()
 
+        if (secondaryLoad) {
+          this.zoomHelper.zoomFit(true, false)
+        }
+
         // zoom to fit all nodes
         if (this.zoomHelper.isAutoZoomToFit() || firstLayout || searchChanged) {
           this.zoomHelper.zoomFit(false, searchChanged)
@@ -548,7 +569,8 @@ class DiagramViewer extends React.Component {
 
         // whether it was used or not, turn it off
         if (this.layoutLoadingRef) {
-          this.layoutLoadingRef.style.visibility = 'hidden'
+          //this.layoutLoadingRef.style.visibility = 'hidden'
+          this.layoutLoadingRef.style.display = 'none'
         }
       }
     )
