@@ -1,12 +1,13 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * Note to U.S. Government Users Restricted Rights:
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
- *******************************************************************************/
+ ****************************************************************************** */
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import * as d3 from 'd3'
@@ -178,7 +179,7 @@ export default class LinkHelper {
       }
     })
 
-    links.transition(transition).style(('opacity': 1.0))
+    links.transition(transition).style('opacity', '1.0')
 
     // move line labels
     if (this.diagramOptions.showLineLabels) {
