@@ -1,4 +1,5 @@
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import React from 'react'
@@ -28,7 +29,8 @@ resources(() => {
 const ChannelLabels = ({
   channels,
   locale,
-  showSubscriptionAttributes = true
+  showSubscriptionAttributes = true,
+  isArgoApp = false
 }) => {
   const channelMap = groupByChannelType(channels || [])
   // Create sorting function for channels
@@ -70,9 +72,22 @@ const ChannelLabels = ({
                 let channelTypeAttributes = []
                 if (showSubscriptionAttributes) {
                   if (chType === 'git') {
-                    channelTypeAttributes = ['gitBranch', 'gitPath']
+                    if (isArgoApp) {
+                      channelTypeAttributes = ['gitPath', 'targetRevision']
+                    } else {
+                      channelTypeAttributes = ['gitBranch', 'gitPath']
+                    }
                   } else if (chType === 'helmrepo') {
-                    channelTypeAttributes = ['package', 'packageFilterVersion']
+                    if (isArgoApp) {
+                      channelTypeAttributes = ['chart', 'targetRevision']
+                    } else {
+                      channelTypeAttributes = [
+                        'package',
+                        'packageFilterVersion'
+                      ]
+                    }
+                  } else if (chType === 'objectbucket') {
+                    channelTypeAttributes = ['bucketPath']
                   }
                 }
                 return (
@@ -139,6 +154,7 @@ const ChannelLabels = ({
 
 ChannelLabels.propTypes = {
   channels: PropTypes.arrayOf(PropTypes.object),
+  isArgoApp: PropTypes.bool,
   locale: PropTypes.string,
   showSubscriptionAttributes: PropTypes.bool
 }
