@@ -13,7 +13,7 @@
 
 import React, { Component } from 'react'
 import msgs from '../../../nls/platform.properties'
-import { AcmButton } from '@open-cluster-management/ui-components'
+import { AcmButton } from '@stolostron/ui-components'
 import { Tooltip } from '@patternfly/react-core'
 import { Link } from 'react-router-dom'
 import config from '../../../lib/shared/config'
