@@ -1,12 +1,13 @@
-/*******************************************************************************
- * Copyright (c) 2020 Red Hat, Inc.
- *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
-const config = JSON.parse(Cypress.env("TEST_CONFIG"));
+const config = Cypress.env("IS_CANARY")
+  ? Cypress.env("TEST_CONFIG_EXCLUDE_ARGO")
+  : Cypress.env("TEST_CONFIG");
 import { validateResourceTable } from "../../views/application";
 import { getNumberOfManagedClusters } from "../../views/resources";
 
-describe("Application UI: [P1][Sev1][app-lifecycle-ui] Application Validation Test for applications table", () => {
+describe("Application UI: [P2][Sev2][app-lifecycle-ui] Application Validation Test for applications table", () => {
   it(`get the number of the managed OCP clusters`, () => {
     getNumberOfManagedClusters();
   });
@@ -18,7 +19,14 @@ describe("Application UI: [P1][Sev1][app-lifecycle-ui] Application Validation Te
           data.name
         } info from applications table - ${type}: ${data.name}`, () => {
           const numberOfRemoteClusters = Cypress.env("numberOfManagedClusters");
-          validateResourceTable(data.name, data, numberOfRemoteClusters);
+          validateResourceTable(
+            data.name,
+            data,
+            type,
+            numberOfRemoteClusters,
+            data.namespace,
+            data.deployedNamespace
+          );
         });
       } else {
         it(`disable validation on resource ${type}`, () => {
